| lifetime_dist | R Documentation |
Computes the implied lifetime cumulative distribution function (CDF),
probability density function (PDF), survival function, and quantiles with
asymptotic confidence intervals for a predefined failure threshold \rho.
lifetime_dist(
object,
threshold,
times = NULL,
probs = c(0.01, 0.05, 0.1, 0.5, 0.8),
conf_level = 0.95
)
object |
An object of class |
threshold |
Numeric failure threshold |
times |
Optional numeric vector of evaluation time points. If |
probs |
Numeric vector of quantile probabilities. Default is |
conf_level |
Nominal confidence level for quantile asymptotic confidence intervals. Default is |
In threshold degradation models, the soft failure time T is defined as:
T = \inf\{t \ge 0 : D(t) \ge \rho\}
The lifetime CDF F_T(t) is the probability that cumulative degradation exceeds \rho:
F_T(t) = P(D(t) \ge \rho) = 1 - F(\rho \mid g_\theta(t), \eta, \xi) = R(\rho \mid g_\theta(t), \eta, \xi)
For the **classical IGP** model:
F_{T,\text{IGP}}(t) = \Phi\left(-\sqrt{\frac{\eta}{\rho}}(\rho - g_\theta(t))\right) - \exp(2\eta g_\theta(t)) \Phi\left(-\sqrt{\frac{\eta}{\rho}}(\rho + g_\theta(t))\right)
For the **IGP-Gamma** model:
F_{T,\text{Gamma}}(t) = \frac{2 \xi^{-1/(2\xi)} (H_{\text{IGP}}(\rho))^{1/(2\xi)} K_{1/\xi}\left(2\sqrt{\frac{H_{\text{IGP}}(\rho)}{\xi}}\right)}{\Gamma(1/\xi)}
For the **IGP-IG** model:
F_{T,\text{IG}}(t) = \frac{\exp\left(-\frac{\sqrt{1 + 2\xi H_{\text{IGP}}(\rho)} - 1}{\xi}\right)}{\sqrt{1 + 2\xi H_{\text{IGP}}(\rho)}}
where H_{\text{IGP}}(\rho) = -\log R_{\text{IGP}}(\rho \mid g_\theta(t), \eta).
Quantiles t_p are computed by numerical root finding on F_T(t_p) = p.
Asymptotic standard errors for \hat t_p are obtained via the Delta method using
the estimated variance-covariance matrix of parameter estimates.
An object of class "lifetime_dist" containing:
threshold |
The specified failure threshold |
quantiles |
Data frame containing estimated quantiles |
curve |
Data frame with evaluation grid: |
conf_level |
Nominal confidence level. |
Morita, L. H. M., Tomazella, V. L. D., Balakrishnan, N., Ramos, P. L., Ferreira, P. H., & Louzada, F. (2021). Inverse Gaussian process model with frailty term in reliability analysis. Quality and Reliability Engineering International, 37(2), 763-784. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/qre.2762")}.
igp_fit, individual_frailty
data(laser)
fit_gam <- igp_fit(laser, time_col = "t", deg_col = "increase",
unit_col = "unit", frailty = "gamma")
lt <- lifetime_dist(fit_gam, threshold = 10, probs = c(0.01, 0.05, 0.1, 0.5, 0.8))
print(lt)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.