| print.igp_fit | R Documentation |
Standard S3 methods for objects of class "igp_fit": print,
summary, coef, vcov, logLik, AIC,
BIC, confint, predict, and plot.
## S3 method for class 'igp_fit'
print(x, digits = 4, ...)
## S3 method for class 'igp_fit'
summary(object, conf_level = 0.95, ...)
## S3 method for class 'summary_igp_fit'
print(x, digits = 4, ...)
## S3 method for class 'igp_fit'
coef(object, ...)
## S3 method for class 'igp_fit'
vcov(object, ...)
## S3 method for class 'igp_fit'
logLik(object, ...)
## S3 method for class 'igp_fit'
AIC(object, ..., k = 2)
## S3 method for class 'igp_fit'
BIC(object, ...)
## S3 method for class 'igp_fit'
confint(object, parm, level = 0.95, ...)
## S3 method for class 'igp_fit'
predict(
object,
newdata = NULL,
threshold = NULL,
times = NULL,
probs = c(0.01, 0.05, 0.1, 0.5, 0.8),
type = c("lifetime", "frailty", "quantiles"),
...
)
## S3 method for class 'igp_fit'
plot(
x,
type = c("paths", "frailty", "lifetime", "diagnostics", "all"),
threshold = NULL,
...
)
x, object |
An object of class |
digits |
Integer indicating the number of decimal places to format. Default is |
... |
Further arguments passed to or from other methods. |
conf_level, level |
Nominal confidence level (e.g. 0.95 for 95% confidence intervals). Default is |
k |
Optional numeric penalty per parameter for |
parm |
Optional vector of numbers or parameter names to compute confidence intervals for. |
newdata |
Optional new data frame for prediction. |
threshold |
Failure threshold |
times |
Numeric vector of inspection times for lifetime predictions. |
probs |
Numeric vector of quantile probabilities. Default is |
type |
For |
print.igp_fit: Prints model summary and returns x invisibly.
summary.igp_fit: Returns an object of class "summary_igp_fit".
coef.igp_fit: Returns named vector of estimated parameters.
vcov.igp_fit: Returns the variance-covariance matrix.
logLik.igp_fit: Returns log-likelihood with degrees of freedom and observations.
AIC.igp_fit, BIC.igp_fit: Return model selection criterion values.
confint.igp_fit: Returns confidence interval matrix.
predict.igp_fit: Returns predicted lifetime distribution, quantiles, or frailties.
plot.igp_fit: Generates base graphics diagnostic and predictive plots.
igp_fit, individual_frailty, lifetime_dist
data(laser)
fit <- igp_fit(laser, time_col = "t", deg_col = "increase",
unit_col = "unit", frailty = "gamma")
print(fit)
summary(fit)
coef(fit)
vcov(fit)
logLik(fit)
AIC(fit)
BIC(fit)
confint(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.